# Copyright 2019 DeepMind Technologies Limited. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or  implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Utilities for interfacing dm_env and dm_env_rpc."""

from dm_env import specs
import numpy as np

from dm_env_rpc.v1 import tensor_utils


def _np_range_info(np_type):
  """Returns type info for `np_type`, which includes min and max attributes."""
  if issubclass(np_type, np.floating):
    return np.finfo(np_type)
  elif issubclass(np_type, np.integer):
    return np.iinfo(np_type)
  else:
    raise ValueError('{} does not have range info.'.format(np_type))


def _find_extreme(tensor_spec, tensor_type, extremal_name):
  """Finds the min or max value the tensor spec sets."""
  explicit_extreme = None
  if tensor_spec.HasField(extremal_name):
    explicit_extreme = getattr(tensor_spec, extremal_name)
  if explicit_extreme is not None:
    value_field = explicit_extreme.WhichOneof('value')
    if value_field is None:
      raise ValueError(
          'Tensor spec had {} present but no value was given.'.format(
              extremal_name))
    if getattr(np, value_field) != tensor_type:
      raise ValueError(
          'Tensor spec had {}.{} set, but tensor has type {}.'.format(
              extremal_name, value_field, tensor_type))
    return getattr(explicit_extreme, value_field)
  else:
    return getattr(_np_range_info(tensor_type), extremal_name)


def tensor_spec_to_dm_env_spec(tensor_spec):
  """Returns the dm_env Array or BoundedArray given a dm_env_rpc TensorSpec."""
  tensor_type = tensor_utils.data_type_to_np_type(tensor_spec.dtype)
  if tensor_spec.HasField('min') or tensor_spec.HasField('max'):
    return specs.BoundedArray(
        shape=tensor_spec.shape,
        dtype=tensor_type,
        name=tensor_spec.name,
        minimum=_find_extreme(tensor_spec, tensor_type, 'min'),
        maximum=_find_extreme(tensor_spec, tensor_type, 'max'))
  else:
    return specs.Array(
        shape=tensor_spec.shape, dtype=tensor_type, name=tensor_spec.name)


def dm_env_spec(spec_manager):
  """Returns a dm_env spec for the given `spec_manager`.

  Args:
    spec_manager: An instance of SpecManager.

  Returns:
    A dict mapping names to either dm_env ArraySpecs or BoundedArraySpecs for
    each named TensorSpec in `spec_manager`.
  """
  return {
      name: tensor_spec_to_dm_env_spec(spec_manager.name_to_spec(name))
      for name in spec_manager.names()
  }



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from dm_env_rpc.v1 import dm_env_rpc_pb2 as dm__env__rpc_dot_v1_dot_dm__env__rpc__pb2


class EnvironmentStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Process = channel.stream_stream(
        '/dm_env_rpc.v1.Environment/Process',
        request_serializer=dm__env__rpc_dot_v1_dot_dm__env__rpc__pb2.EnvironmentRequest.SerializeToString,
        response_deserializer=dm__env__rpc_dot_v1_dot_dm__env__rpc__pb2.EnvironmentResponse.FromString,
        )


class EnvironmentServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Process(self, request_iterator, context):
    """Process incoming environment requests.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EnvironmentServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Process': grpc.stream_stream_rpc_method_handler(
          servicer.Process,
          request_deserializer=dm__env__rpc_dot_v1_dot_dm__env__rpc__pb2.EnvironmentRequest.FromString,
          response_serializer=dm__env__rpc_dot_v1_dot_dm__env__rpc__pb2.EnvironmentResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dm_env_rpc.v1.Environment', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dm_env_rpc/v1/dm_env_rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dm_env_rpc/v1/dm_env_rpc.proto',
  package='dm_env_rpc.v1',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1e\x64m_env_rpc/v1/dm_env_rpc.proto\x12\rdm_env_rpc.v1\x1a\x19google/protobuf/any.proto\x1a\x17google/rpc/status.proto\"\xb9\x07\n\x06Tensor\x12\x32\n\x06\x66loats\x18\x01 \x01(\x0b\x32 .dm_env_rpc.v1.Tensor.FloatArrayH\x00\x12\x34\n\x07\x64oubles\x18\x02 \x01(\x0b\x32!.dm_env_rpc.v1.Tensor.DoubleArrayH\x00\x12\x30\n\x05int8s\x18\x03 \x01(\x0b\x32\x1f.dm_env_rpc.v1.Tensor.Int8ArrayH\x00\x12\x32\n\x06int32s\x18\x04 \x01(\x0b\x32 .dm_env_rpc.v1.Tensor.Int32ArrayH\x00\x12\x32\n\x06int64s\x18\x05 \x01(\x0b\x32 .dm_env_rpc.v1.Tensor.Int64ArrayH\x00\x12\x32\n\x06uint8s\x18\x06 \x01(\x0b\x32 .dm_env_rpc.v1.Tensor.Uint8ArrayH\x00\x12\x34\n\x07uint32s\x18\x07 \x01(\x0b\x32!.dm_env_rpc.v1.Tensor.Uint32ArrayH\x00\x12\x34\n\x07uint64s\x18\x08 \x01(\x0b\x32!.dm_env_rpc.v1.Tensor.Uint64ArrayH\x00\x12\x30\n\x05\x62ools\x18\t \x01(\x0b\x32\x1f.dm_env_rpc.v1.Tensor.BoolArrayH\x00\x12\x34\n\x07strings\x18\n \x01(\x0b\x32!.dm_env_rpc.v1.Tensor.StringArrayH\x00\x12\x32\n\x06protos\x18\x0b \x01(\x0b\x32 .dm_env_rpc.v1.Tensor.ProtoArrayH\x00\x12\r\n\x05shape\x18\x0f \x03(\x05\x1a\x1a\n\tInt8Array\x12\r\n\x05\x61rray\x18\x01 \x01(\x0c\x1a\x1b\n\nInt32Array\x12\r\n\x05\x61rray\x18\x01 \x03(\x05\x1a\x1b\n\nInt64Array\x12\r\n\x05\x61rray\x18\x01 \x03(\x03\x1a\x1b\n\nUint8Array\x12\r\n\x05\x61rray\x18\x01 \x01(\x0c\x1a\x1c\n\x0bUint32Array\x12\r\n\x05\x61rray\x18\x01 \x03(\r\x1a\x1c\n\x0bUint64Array\x12\r\n\x05\x61rray\x18\x01 \x03(\x04\x1a\x1b\n\nFloatArray\x12\r\n\x05\x61rray\x18\x01 \x03(\x02\x1a\x1c\n\x0b\x44oubleArray\x12\r\n\x05\x61rray\x18\x01 \x03(\x01\x1a\x1a\n\tBoolArray\x12\r\n\x05\x61rray\x18\x01 \x03(\x08\x1a\x1c\n\x0bStringArray\x12\r\n\x05\x61rray\x18\x01 \x03(\t\x1a\x31\n\nProtoArray\x12#\n\x05\x61rray\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\t\n\x07payload\"\xa8\x02\n\nTensorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x05\x12&\n\x05\x64type\x18\x03 \x01(\x0e\x32\x17.dm_env_rpc.v1.DataType\x12,\n\x03min\x18\x04 \x01(\x0b\x32\x1f.dm_env_rpc.v1.TensorSpec.Value\x12,\n\x03max\x18\x05 \x01(\x0b\x32\x1f.dm_env_rpc.v1.TensorSpec.Value\x1ay\n\x05Value\x12\x0f\n\x05\x66loat\x18\x01 \x01(\x02H\x00\x12\x10\n\x06\x64ouble\x18\x02 \x01(\x01H\x00\x12\x0f\n\x05int32\x18\x03 \x01(\x05H\x00\x12\x0f\n\x05int64\x18\x04 \x01(\x03H\x00\x12\x10\n\x06uint32\x18\x05 \x01(\rH\x00\x12\x10\n\x06uint64\x18\x06 \x01(\x04H\x00\x42\x07\n\x05value\"\x9f\x01\n\x12\x43reateWorldRequest\x12\x41\n\x08settings\x18\x01 \x03(\x0b\x32/.dm_env_rpc.v1.CreateWorldRequest.SettingsEntry\x1a\x46\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\")\n\x13\x43reateWorldResponse\x12\x12\n\nworld_name\x18\x01 \x01(\t\"\xc7\x02\n\x16\x41\x63tionObservationSpecs\x12\x43\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x32.dm_env_rpc.v1.ActionObservationSpecs.ActionsEntry\x12M\n\x0cobservations\x18\x02 \x03(\x0b\x32\x37.dm_env_rpc.v1.ActionObservationSpecs.ObservationsEntry\x1aI\n\x0c\x41\x63tionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.dm_env_rpc.v1.TensorSpec:\x02\x38\x01\x1aN\n\x11ObservationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.dm_env_rpc.v1.TensorSpec:\x02\x38\x01\"\xaf\x01\n\x10JoinWorldRequest\x12\x12\n\nworld_name\x18\x01 \x01(\t\x12?\n\x08settings\x18\x02 \x03(\x0b\x32-.dm_env_rpc.v1.JoinWorldRequest.SettingsEntry\x1a\x46\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"I\n\x11JoinWorldResponse\x12\x34\n\x05specs\x18\x01 \x01(\x0b\x32%.dm_env_rpc.v1.ActionObservationSpecs\"\xae\x01\n\x0bStepRequest\x12\x38\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\'.dm_env_rpc.v1.StepRequest.ActionsEntry\x12\x1e\n\x16requested_observations\x18\x02 \x03(\x04\x1a\x45\n\x0c\x41\x63tionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"\xd3\x01\n\x0cStepResponse\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.dm_env_rpc.v1.EnvironmentStateType\x12\x43\n\x0cobservations\x18\x02 \x03(\x0b\x32-.dm_env_rpc.v1.StepResponse.ObservationsEntry\x1aJ\n\x11ObservationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"\x93\x01\n\x0cResetRequest\x12;\n\x08settings\x18\x01 \x03(\x0b\x32).dm_env_rpc.v1.ResetRequest.SettingsEntry\x1a\x46\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"E\n\rResetResponse\x12\x34\n\x05specs\x18\x01 \x01(\x0b\x32%.dm_env_rpc.v1.ActionObservationSpecs\"\xb1\x01\n\x11ResetWorldRequest\x12\x12\n\nworld_name\x18\x01 \x01(\t\x12@\n\x08settings\x18\x02 \x03(\x0b\x32..dm_env_rpc.v1.ResetWorldRequest.SettingsEntry\x1a\x46\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"\x14\n\x12ResetWorldResponse\"\x13\n\x11LeaveWorldRequest\"\x14\n\x12LeaveWorldResponse\")\n\x13\x44\x65stroyWorldRequest\x12\x12\n\nworld_name\x18\x01 \x01(\t\"\x16\n\x14\x44\x65stroyWorldResponse\"#\n\x13ReadPropertyRequest\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xa9\x01\n\x14ReadPropertyResponse\x12G\n\nproperties\x18\x01 \x03(\x0b\x32\x33.dm_env_rpc.v1.ReadPropertyResponse.PropertiesEntry\x1aH\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"\xa9\x01\n\x14WritePropertyRequest\x12G\n\nproperties\x18\x01 \x03(\x0b\x32\x33.dm_env_rpc.v1.WritePropertyRequest.PropertiesEntry\x1aH\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.dm_env_rpc.v1.Tensor:\x02\x38\x01\"\x17\n\x15WritePropertyResponse\"#\n\x13ListPropertyRequest\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xb5\x02\n\x14ListPropertyResponse\x12G\n\nproperties\x18\x01 \x03(\x0b\x32\x33.dm_env_rpc.v1.ListPropertyResponse.PropertiesEntry\x1as\n\x08Property\x12\x13\n\x0bis_readable\x18\x01 \x01(\x08\x12\x14\n\x0cis_writeable\x18\x02 \x01(\x08\x12\x13\n\x0bis_listable\x18\x03 \x01(\x08\x12\'\n\x04spec\x18\x04 \x01(\x0b\x32\x19.dm_env_rpc.v1.TensorSpec\x1a_\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.dm_env_rpc.v1.ListPropertyResponse.Property:\x02\x38\x01\"\x84\x05\n\x12\x45nvironmentRequest\x12\x39\n\x0c\x63reate_world\x18\x01 \x01(\x0b\x32!.dm_env_rpc.v1.CreateWorldRequestH\x00\x12\x35\n\njoin_world\x18\x02 \x01(\x0b\x32\x1f.dm_env_rpc.v1.JoinWorldRequestH\x00\x12*\n\x04step\x18\x03 \x01(\x0b\x32\x1a.dm_env_rpc.v1.StepRequestH\x00\x12,\n\x05reset\x18\x04 \x01(\x0b\x32\x1b.dm_env_rpc.v1.ResetRequestH\x00\x12\x37\n\x0breset_world\x18\x05 \x01(\x0b\x32 .dm_env_rpc.v1.ResetWorldRequestH\x00\x12\x37\n\x0bleave_world\x18\x06 \x01(\x0b\x32 .dm_env_rpc.v1.LeaveWorldRequestH\x00\x12;\n\rdestroy_world\x18\x07 \x01(\x0b\x32\".dm_env_rpc.v1.DestroyWorldRequestH\x00\x12;\n\rread_property\x18\x08 \x01(\x0b\x32\".dm_env_rpc.v1.ReadPropertyRequestH\x00\x12=\n\x0ewrite_property\x18\t \x01(\x0b\x32#.dm_env_rpc.v1.WritePropertyRequestH\x00\x12;\n\rlist_property\x18\n \x01(\x0b\x32\".dm_env_rpc.v1.ListPropertyRequestH\x00\x12)\n\textension\x18\x0f \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\t\n\x07payloadJ\x04\x08\x10\x10\x11\"\xae\x05\n\x13\x45nvironmentResponse\x12:\n\x0c\x63reate_world\x18\x01 \x01(\x0b\x32\".dm_env_rpc.v1.CreateWorldResponseH\x00\x12\x36\n\njoin_world\x18\x02 \x01(\x0b\x32 .dm_env_rpc.v1.JoinWorldResponseH\x00\x12+\n\x04step\x18\x03 \x01(\x0b\x32\x1b.dm_env_rpc.v1.StepResponseH\x00\x12-\n\x05reset\x18\x04 \x01(\x0b\x32\x1c.dm_env_rpc.v1.ResetResponseH\x00\x12\x38\n\x0breset_world\x18\x05 \x01(\x0b\x32!.dm_env_rpc.v1.ResetWorldResponseH\x00\x12\x38\n\x0bleave_world\x18\x06 \x01(\x0b\x32!.dm_env_rpc.v1.LeaveWorldResponseH\x00\x12<\n\rdestroy_world\x18\x07 \x01(\x0b\x32#.dm_env_rpc.v1.DestroyWorldResponseH\x00\x12<\n\rread_property\x18\x08 \x01(\x0b\x32#.dm_env_rpc.v1.ReadPropertyResponseH\x00\x12>\n\x0ewrite_property\x18\t \x01(\x0b\x32$.dm_env_rpc.v1.WritePropertyResponseH\x00\x12<\n\rlist_property\x18\n \x01(\x0b\x32#.dm_env_rpc.v1.ListPropertyResponseH\x00\x12)\n\textension\x18\x0f \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12#\n\x05\x65rror\x18\x10 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload*\x9c\x01\n\x08\x44\x61taType\x12\x15\n\x11INVALID_DATA_TYPE\x10\x00\x12\t\n\x05\x46LOAT\x10\x01\x12\n\n\x06\x44OUBLE\x10\x02\x12\x08\n\x04INT8\x10\x03\x12\t\n\x05INT32\x10\x04\x12\t\n\x05INT64\x10\x05\x12\t\n\x05UINT8\x10\x06\x12\n\n\x06UINT32\x10\x07\x12\n\n\x06UINT64\x10\x08\x12\x08\n\x04\x42OOL\x10\t\x12\n\n\x06STRING\x10\n\x12\t\n\x05PROTO\x10\x0b*c\n\x14\x45nvironmentStateType\x12\x1d\n\x19INVALID_ENVIRONMENT_STATE\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0e\n\nTERMINATED\x10\x02\x12\x0f\n\x0bINTERRUPTED\x10\x03\x32\x65\n\x0b\x45nvironment\x12V\n\x07Process\x12!.dm_env_rpc.v1.EnvironmentRequest\x1a\".dm_env_rpc.v1.EnvironmentResponse\"\x00(\x01\x30\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])

_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='dm_env_rpc.v1.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATA_TYPE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT8', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT8', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT32', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTO', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5160,
  serialized_end=5316,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE)

DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
_ENVIRONMENTSTATETYPE = _descriptor.EnumDescriptor(
  name='EnvironmentStateType',
  full_name='dm_env_rpc.v1.EnvironmentStateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID_ENVIRONMENT_STATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERRUPTED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5318,
  serialized_end=5417,
)
_sym_db.RegisterEnumDescriptor(_ENVIRONMENTSTATETYPE)

EnvironmentStateType = enum_type_wrapper.EnumTypeWrapper(_ENVIRONMENTSTATETYPE)
INVALID_DATA_TYPE = 0
FLOAT = 1
DOUBLE = 2
INT8 = 3
INT32 = 4
INT64 = 5
UINT8 = 6
UINT32 = 7
UINT64 = 8
BOOL = 9
STRING = 10
PROTO = 11
INVALID_ENVIRONMENT_STATE = 0
RUNNING = 1
TERMINATED = 2
INTERRUPTED = 3



_TENSOR_INT8ARRAY = _descriptor.Descriptor(
  name='Int8Array',
  full_name='dm_env_rpc.v1.Tensor.Int8Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Int8Array.array', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=729,
)

_TENSOR_INT32ARRAY = _descriptor.Descriptor(
  name='Int32Array',
  full_name='dm_env_rpc.v1.Tensor.Int32Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Int32Array.array', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=758,
)

_TENSOR_INT64ARRAY = _descriptor.Descriptor(
  name='Int64Array',
  full_name='dm_env_rpc.v1.Tensor.Int64Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Int64Array.array', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=787,
)

_TENSOR_UINT8ARRAY = _descriptor.Descriptor(
  name='Uint8Array',
  full_name='dm_env_rpc.v1.Tensor.Uint8Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Uint8Array.array', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=816,
)

_TENSOR_UINT32ARRAY = _descriptor.Descriptor(
  name='Uint32Array',
  full_name='dm_env_rpc.v1.Tensor.Uint32Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Uint32Array.array', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=846,
)

_TENSOR_UINT64ARRAY = _descriptor.Descriptor(
  name='Uint64Array',
  full_name='dm_env_rpc.v1.Tensor.Uint64Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.Uint64Array.array', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=876,
)

_TENSOR_FLOATARRAY = _descriptor.Descriptor(
  name='FloatArray',
  full_name='dm_env_rpc.v1.Tensor.FloatArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.FloatArray.array', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=905,
)

_TENSOR_DOUBLEARRAY = _descriptor.Descriptor(
  name='DoubleArray',
  full_name='dm_env_rpc.v1.Tensor.DoubleArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.DoubleArray.array', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=935,
)

_TENSOR_BOOLARRAY = _descriptor.Descriptor(
  name='BoolArray',
  full_name='dm_env_rpc.v1.Tensor.BoolArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.BoolArray.array', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=963,
)

_TENSOR_STRINGARRAY = _descriptor.Descriptor(
  name='StringArray',
  full_name='dm_env_rpc.v1.Tensor.StringArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.StringArray.array', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=993,
)

_TENSOR_PROTOARRAY = _descriptor.Descriptor(
  name='ProtoArray',
  full_name='dm_env_rpc.v1.Tensor.ProtoArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='dm_env_rpc.v1.Tensor.ProtoArray.array', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1044,
)

_TENSOR = _descriptor.Descriptor(
  name='Tensor',
  full_name='dm_env_rpc.v1.Tensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='floats', full_name='dm_env_rpc.v1.Tensor.floats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='dm_env_rpc.v1.Tensor.doubles', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int8s', full_name='dm_env_rpc.v1.Tensor.int8s', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32s', full_name='dm_env_rpc.v1.Tensor.int32s', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64s', full_name='dm_env_rpc.v1.Tensor.int64s', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint8s', full_name='dm_env_rpc.v1.Tensor.uint8s', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32s', full_name='dm_env_rpc.v1.Tensor.uint32s', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64s', full_name='dm_env_rpc.v1.Tensor.uint64s', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bools', full_name='dm_env_rpc.v1.Tensor.bools', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strings', full_name='dm_env_rpc.v1.Tensor.strings', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protos', full_name='dm_env_rpc.v1.Tensor.protos', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='dm_env_rpc.v1.Tensor.shape', index=11,
      number=15, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TENSOR_INT8ARRAY, _TENSOR_INT32ARRAY, _TENSOR_INT64ARRAY, _TENSOR_UINT8ARRAY, _TENSOR_UINT32ARRAY, _TENSOR_UINT64ARRAY, _TENSOR_FLOATARRAY, _TENSOR_DOUBLEARRAY, _TENSOR_BOOLARRAY, _TENSOR_STRINGARRAY, _TENSOR_PROTOARRAY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='dm_env_rpc.v1.Tensor.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=102,
  serialized_end=1055,
)


_TENSORSPEC_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='dm_env_rpc.v1.TensorSpec.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='float', full_name='dm_env_rpc.v1.TensorSpec.Value.float', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double', full_name='dm_env_rpc.v1.TensorSpec.Value.double', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32', full_name='dm_env_rpc.v1.TensorSpec.Value.int32', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64', full_name='dm_env_rpc.v1.TensorSpec.Value.int64', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32', full_name='dm_env_rpc.v1.TensorSpec.Value.uint32', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64', full_name='dm_env_rpc.v1.TensorSpec.Value.uint64', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='dm_env_rpc.v1.TensorSpec.Value.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1233,
  serialized_end=1354,
)

_TENSORSPEC = _descriptor.Descriptor(
  name='TensorSpec',
  full_name='dm_env_rpc.v1.TensorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dm_env_rpc.v1.TensorSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='dm_env_rpc.v1.TensorSpec.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='dm_env_rpc.v1.TensorSpec.dtype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='dm_env_rpc.v1.TensorSpec.min', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='dm_env_rpc.v1.TensorSpec.max', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TENSORSPEC_VALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1354,
)


_CREATEWORLDREQUEST_SETTINGSENTRY = _descriptor.Descriptor(
  name='SettingsEntry',
  full_name='dm_env_rpc.v1.CreateWorldRequest.SettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.CreateWorldRequest.SettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.CreateWorldRequest.SettingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1516,
)

_CREATEWORLDREQUEST = _descriptor.Descriptor(
  name='CreateWorldRequest',
  full_name='dm_env_rpc.v1.CreateWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='dm_env_rpc.v1.CreateWorldRequest.settings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEWORLDREQUEST_SETTINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1516,
)


_CREATEWORLDRESPONSE = _descriptor.Descriptor(
  name='CreateWorldResponse',
  full_name='dm_env_rpc.v1.CreateWorldResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_name', full_name='dm_env_rpc.v1.CreateWorldResponse.world_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1518,
  serialized_end=1559,
)


_ACTIONOBSERVATIONSPECS_ACTIONSENTRY = _descriptor.Descriptor(
  name='ActionsEntry',
  full_name='dm_env_rpc.v1.ActionObservationSpecs.ActionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ActionObservationSpecs.ActionsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ActionObservationSpecs.ActionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1736,
  serialized_end=1809,
)

_ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY = _descriptor.Descriptor(
  name='ObservationsEntry',
  full_name='dm_env_rpc.v1.ActionObservationSpecs.ObservationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ActionObservationSpecs.ObservationsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ActionObservationSpecs.ObservationsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1889,
)

_ACTIONOBSERVATIONSPECS = _descriptor.Descriptor(
  name='ActionObservationSpecs',
  full_name='dm_env_rpc.v1.ActionObservationSpecs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='dm_env_rpc.v1.ActionObservationSpecs.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observations', full_name='dm_env_rpc.v1.ActionObservationSpecs.observations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACTIONOBSERVATIONSPECS_ACTIONSENTRY, _ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1889,
)


_JOINWORLDREQUEST_SETTINGSENTRY = _descriptor.Descriptor(
  name='SettingsEntry',
  full_name='dm_env_rpc.v1.JoinWorldRequest.SettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.JoinWorldRequest.SettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.JoinWorldRequest.SettingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1516,
)

_JOINWORLDREQUEST = _descriptor.Descriptor(
  name='JoinWorldRequest',
  full_name='dm_env_rpc.v1.JoinWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_name', full_name='dm_env_rpc.v1.JoinWorldRequest.world_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='dm_env_rpc.v1.JoinWorldRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_JOINWORLDREQUEST_SETTINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=2067,
)


_JOINWORLDRESPONSE = _descriptor.Descriptor(
  name='JoinWorldResponse',
  full_name='dm_env_rpc.v1.JoinWorldResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specs', full_name='dm_env_rpc.v1.JoinWorldResponse.specs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2069,
  serialized_end=2142,
)


_STEPREQUEST_ACTIONSENTRY = _descriptor.Descriptor(
  name='ActionsEntry',
  full_name='dm_env_rpc.v1.StepRequest.ActionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.StepRequest.ActionsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.StepRequest.ActionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2250,
  serialized_end=2319,
)

_STEPREQUEST = _descriptor.Descriptor(
  name='StepRequest',
  full_name='dm_env_rpc.v1.StepRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='dm_env_rpc.v1.StepRequest.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requested_observations', full_name='dm_env_rpc.v1.StepRequest.requested_observations', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STEPREQUEST_ACTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2145,
  serialized_end=2319,
)


_STEPRESPONSE_OBSERVATIONSENTRY = _descriptor.Descriptor(
  name='ObservationsEntry',
  full_name='dm_env_rpc.v1.StepResponse.ObservationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.StepResponse.ObservationsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.StepResponse.ObservationsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2533,
)

_STEPRESPONSE = _descriptor.Descriptor(
  name='StepResponse',
  full_name='dm_env_rpc.v1.StepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='dm_env_rpc.v1.StepResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observations', full_name='dm_env_rpc.v1.StepResponse.observations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STEPRESPONSE_OBSERVATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2322,
  serialized_end=2533,
)


_RESETREQUEST_SETTINGSENTRY = _descriptor.Descriptor(
  name='SettingsEntry',
  full_name='dm_env_rpc.v1.ResetRequest.SettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ResetRequest.SettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ResetRequest.SettingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1516,
)

_RESETREQUEST = _descriptor.Descriptor(
  name='ResetRequest',
  full_name='dm_env_rpc.v1.ResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='settings', full_name='dm_env_rpc.v1.ResetRequest.settings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESETREQUEST_SETTINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2536,
  serialized_end=2683,
)


_RESETRESPONSE = _descriptor.Descriptor(
  name='ResetResponse',
  full_name='dm_env_rpc.v1.ResetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specs', full_name='dm_env_rpc.v1.ResetResponse.specs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2685,
  serialized_end=2754,
)


_RESETWORLDREQUEST_SETTINGSENTRY = _descriptor.Descriptor(
  name='SettingsEntry',
  full_name='dm_env_rpc.v1.ResetWorldRequest.SettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ResetWorldRequest.SettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ResetWorldRequest.SettingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1516,
)

_RESETWORLDREQUEST = _descriptor.Descriptor(
  name='ResetWorldRequest',
  full_name='dm_env_rpc.v1.ResetWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_name', full_name='dm_env_rpc.v1.ResetWorldRequest.world_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='dm_env_rpc.v1.ResetWorldRequest.settings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RESETWORLDREQUEST_SETTINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2757,
  serialized_end=2934,
)


_RESETWORLDRESPONSE = _descriptor.Descriptor(
  name='ResetWorldResponse',
  full_name='dm_env_rpc.v1.ResetWorldResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2936,
  serialized_end=2956,
)


_LEAVEWORLDREQUEST = _descriptor.Descriptor(
  name='LeaveWorldRequest',
  full_name='dm_env_rpc.v1.LeaveWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2958,
  serialized_end=2977,
)


_LEAVEWORLDRESPONSE = _descriptor.Descriptor(
  name='LeaveWorldResponse',
  full_name='dm_env_rpc.v1.LeaveWorldResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=2999,
)


_DESTROYWORLDREQUEST = _descriptor.Descriptor(
  name='DestroyWorldRequest',
  full_name='dm_env_rpc.v1.DestroyWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_name', full_name='dm_env_rpc.v1.DestroyWorldRequest.world_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3001,
  serialized_end=3042,
)


_DESTROYWORLDRESPONSE = _descriptor.Descriptor(
  name='DestroyWorldResponse',
  full_name='dm_env_rpc.v1.DestroyWorldResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3044,
  serialized_end=3066,
)


_READPROPERTYREQUEST = _descriptor.Descriptor(
  name='ReadPropertyRequest',
  full_name='dm_env_rpc.v1.ReadPropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='dm_env_rpc.v1.ReadPropertyRequest.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3068,
  serialized_end=3103,
)


_READPROPERTYRESPONSE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='dm_env_rpc.v1.ReadPropertyResponse.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ReadPropertyResponse.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ReadPropertyResponse.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3203,
  serialized_end=3275,
)

_READPROPERTYRESPONSE = _descriptor.Descriptor(
  name='ReadPropertyResponse',
  full_name='dm_env_rpc.v1.ReadPropertyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='dm_env_rpc.v1.ReadPropertyResponse.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_READPROPERTYRESPONSE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3106,
  serialized_end=3275,
)


_WRITEPROPERTYREQUEST_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='dm_env_rpc.v1.WritePropertyRequest.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.WritePropertyRequest.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.WritePropertyRequest.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3203,
  serialized_end=3275,
)

_WRITEPROPERTYREQUEST = _descriptor.Descriptor(
  name='WritePropertyRequest',
  full_name='dm_env_rpc.v1.WritePropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='dm_env_rpc.v1.WritePropertyRequest.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WRITEPROPERTYREQUEST_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3278,
  serialized_end=3447,
)


_WRITEPROPERTYRESPONSE = _descriptor.Descriptor(
  name='WritePropertyResponse',
  full_name='dm_env_rpc.v1.WritePropertyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3449,
  serialized_end=3472,
)


_LISTPROPERTYREQUEST = _descriptor.Descriptor(
  name='ListPropertyRequest',
  full_name='dm_env_rpc.v1.ListPropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='dm_env_rpc.v1.ListPropertyRequest.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3474,
  serialized_end=3509,
)


_LISTPROPERTYRESPONSE_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='dm_env_rpc.v1.ListPropertyResponse.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_readable', full_name='dm_env_rpc.v1.ListPropertyResponse.Property.is_readable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_writeable', full_name='dm_env_rpc.v1.ListPropertyResponse.Property.is_writeable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_listable', full_name='dm_env_rpc.v1.ListPropertyResponse.Property.is_listable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='dm_env_rpc.v1.ListPropertyResponse.Property.spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3724,
)

_LISTPROPERTYRESPONSE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='dm_env_rpc.v1.ListPropertyResponse.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dm_env_rpc.v1.ListPropertyResponse.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dm_env_rpc.v1.ListPropertyResponse.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3726,
  serialized_end=3821,
)

_LISTPROPERTYRESPONSE = _descriptor.Descriptor(
  name='ListPropertyResponse',
  full_name='dm_env_rpc.v1.ListPropertyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='dm_env_rpc.v1.ListPropertyResponse.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTPROPERTYRESPONSE_PROPERTY, _LISTPROPERTYRESPONSE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3512,
  serialized_end=3821,
)


_ENVIRONMENTREQUEST = _descriptor.Descriptor(
  name='EnvironmentRequest',
  full_name='dm_env_rpc.v1.EnvironmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_world', full_name='dm_env_rpc.v1.EnvironmentRequest.create_world', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join_world', full_name='dm_env_rpc.v1.EnvironmentRequest.join_world', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step', full_name='dm_env_rpc.v1.EnvironmentRequest.step', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset', full_name='dm_env_rpc.v1.EnvironmentRequest.reset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset_world', full_name='dm_env_rpc.v1.EnvironmentRequest.reset_world', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leave_world', full_name='dm_env_rpc.v1.EnvironmentRequest.leave_world', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destroy_world', full_name='dm_env_rpc.v1.EnvironmentRequest.destroy_world', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_property', full_name='dm_env_rpc.v1.EnvironmentRequest.read_property', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_property', full_name='dm_env_rpc.v1.EnvironmentRequest.write_property', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_property', full_name='dm_env_rpc.v1.EnvironmentRequest.list_property', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension', full_name='dm_env_rpc.v1.EnvironmentRequest.extension', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='dm_env_rpc.v1.EnvironmentRequest.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3824,
  serialized_end=4468,
)


_ENVIRONMENTRESPONSE = _descriptor.Descriptor(
  name='EnvironmentResponse',
  full_name='dm_env_rpc.v1.EnvironmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_world', full_name='dm_env_rpc.v1.EnvironmentResponse.create_world', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='join_world', full_name='dm_env_rpc.v1.EnvironmentResponse.join_world', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step', full_name='dm_env_rpc.v1.EnvironmentResponse.step', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset', full_name='dm_env_rpc.v1.EnvironmentResponse.reset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset_world', full_name='dm_env_rpc.v1.EnvironmentResponse.reset_world', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leave_world', full_name='dm_env_rpc.v1.EnvironmentResponse.leave_world', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destroy_world', full_name='dm_env_rpc.v1.EnvironmentResponse.destroy_world', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_property', full_name='dm_env_rpc.v1.EnvironmentResponse.read_property', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_property', full_name='dm_env_rpc.v1.EnvironmentResponse.write_property', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_property', full_name='dm_env_rpc.v1.EnvironmentResponse.list_property', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension', full_name='dm_env_rpc.v1.EnvironmentResponse.extension', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='dm_env_rpc.v1.EnvironmentResponse.error', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='dm_env_rpc.v1.EnvironmentResponse.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4471,
  serialized_end=5157,
)

_TENSOR_INT8ARRAY.containing_type = _TENSOR
_TENSOR_INT32ARRAY.containing_type = _TENSOR
_TENSOR_INT64ARRAY.containing_type = _TENSOR
_TENSOR_UINT8ARRAY.containing_type = _TENSOR
_TENSOR_UINT32ARRAY.containing_type = _TENSOR
_TENSOR_UINT64ARRAY.containing_type = _TENSOR
_TENSOR_FLOATARRAY.containing_type = _TENSOR
_TENSOR_DOUBLEARRAY.containing_type = _TENSOR
_TENSOR_BOOLARRAY.containing_type = _TENSOR
_TENSOR_STRINGARRAY.containing_type = _TENSOR
_TENSOR_PROTOARRAY.fields_by_name['array'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TENSOR_PROTOARRAY.containing_type = _TENSOR
_TENSOR.fields_by_name['floats'].message_type = _TENSOR_FLOATARRAY
_TENSOR.fields_by_name['doubles'].message_type = _TENSOR_DOUBLEARRAY
_TENSOR.fields_by_name['int8s'].message_type = _TENSOR_INT8ARRAY
_TENSOR.fields_by_name['int32s'].message_type = _TENSOR_INT32ARRAY
_TENSOR.fields_by_name['int64s'].message_type = _TENSOR_INT64ARRAY
_TENSOR.fields_by_name['uint8s'].message_type = _TENSOR_UINT8ARRAY
_TENSOR.fields_by_name['uint32s'].message_type = _TENSOR_UINT32ARRAY
_TENSOR.fields_by_name['uint64s'].message_type = _TENSOR_UINT64ARRAY
_TENSOR.fields_by_name['bools'].message_type = _TENSOR_BOOLARRAY
_TENSOR.fields_by_name['strings'].message_type = _TENSOR_STRINGARRAY
_TENSOR.fields_by_name['protos'].message_type = _TENSOR_PROTOARRAY
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['floats'])
_TENSOR.fields_by_name['floats'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['doubles'])
_TENSOR.fields_by_name['doubles'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['int8s'])
_TENSOR.fields_by_name['int8s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['int32s'])
_TENSOR.fields_by_name['int32s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['int64s'])
_TENSOR.fields_by_name['int64s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['uint8s'])
_TENSOR.fields_by_name['uint8s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['uint32s'])
_TENSOR.fields_by_name['uint32s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['uint64s'])
_TENSOR.fields_by_name['uint64s'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['bools'])
_TENSOR.fields_by_name['bools'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['strings'])
_TENSOR.fields_by_name['strings'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSOR.oneofs_by_name['payload'].fields.append(
  _TENSOR.fields_by_name['protos'])
_TENSOR.fields_by_name['protos'].containing_oneof = _TENSOR.oneofs_by_name['payload']
_TENSORSPEC_VALUE.containing_type = _TENSORSPEC
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['float'])
_TENSORSPEC_VALUE.fields_by_name['float'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['double'])
_TENSORSPEC_VALUE.fields_by_name['double'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['int32'])
_TENSORSPEC_VALUE.fields_by_name['int32'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['int64'])
_TENSORSPEC_VALUE.fields_by_name['int64'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['uint32'])
_TENSORSPEC_VALUE.fields_by_name['uint32'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC_VALUE.oneofs_by_name['value'].fields.append(
  _TENSORSPEC_VALUE.fields_by_name['uint64'])
_TENSORSPEC_VALUE.fields_by_name['uint64'].containing_oneof = _TENSORSPEC_VALUE.oneofs_by_name['value']
_TENSORSPEC.fields_by_name['dtype'].enum_type = _DATATYPE
_TENSORSPEC.fields_by_name['min'].message_type = _TENSORSPEC_VALUE
_TENSORSPEC.fields_by_name['max'].message_type = _TENSORSPEC_VALUE
_CREATEWORLDREQUEST_SETTINGSENTRY.fields_by_name['value'].message_type = _TENSOR
_CREATEWORLDREQUEST_SETTINGSENTRY.containing_type = _CREATEWORLDREQUEST
_CREATEWORLDREQUEST.fields_by_name['settings'].message_type = _CREATEWORLDREQUEST_SETTINGSENTRY
_ACTIONOBSERVATIONSPECS_ACTIONSENTRY.fields_by_name['value'].message_type = _TENSORSPEC
_ACTIONOBSERVATIONSPECS_ACTIONSENTRY.containing_type = _ACTIONOBSERVATIONSPECS
_ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY.fields_by_name['value'].message_type = _TENSORSPEC
_ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY.containing_type = _ACTIONOBSERVATIONSPECS
_ACTIONOBSERVATIONSPECS.fields_by_name['actions'].message_type = _ACTIONOBSERVATIONSPECS_ACTIONSENTRY
_ACTIONOBSERVATIONSPECS.fields_by_name['observations'].message_type = _ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY
_JOINWORLDREQUEST_SETTINGSENTRY.fields_by_name['value'].message_type = _TENSOR
_JOINWORLDREQUEST_SETTINGSENTRY.containing_type = _JOINWORLDREQUEST
_JOINWORLDREQUEST.fields_by_name['settings'].message_type = _JOINWORLDREQUEST_SETTINGSENTRY
_JOINWORLDRESPONSE.fields_by_name['specs'].message_type = _ACTIONOBSERVATIONSPECS
_STEPREQUEST_ACTIONSENTRY.fields_by_name['value'].message_type = _TENSOR
_STEPREQUEST_ACTIONSENTRY.containing_type = _STEPREQUEST
_STEPREQUEST.fields_by_name['actions'].message_type = _STEPREQUEST_ACTIONSENTRY
_STEPRESPONSE_OBSERVATIONSENTRY.fields_by_name['value'].message_type = _TENSOR
_STEPRESPONSE_OBSERVATIONSENTRY.containing_type = _STEPRESPONSE
_STEPRESPONSE.fields_by_name['state'].enum_type = _ENVIRONMENTSTATETYPE
_STEPRESPONSE.fields_by_name['observations'].message_type = _STEPRESPONSE_OBSERVATIONSENTRY
_RESETREQUEST_SETTINGSENTRY.fields_by_name['value'].message_type = _TENSOR
_RESETREQUEST_SETTINGSENTRY.containing_type = _RESETREQUEST
_RESETREQUEST.fields_by_name['settings'].message_type = _RESETREQUEST_SETTINGSENTRY
_RESETRESPONSE.fields_by_name['specs'].message_type = _ACTIONOBSERVATIONSPECS
_RESETWORLDREQUEST_SETTINGSENTRY.fields_by_name['value'].message_type = _TENSOR
_RESETWORLDREQUEST_SETTINGSENTRY.containing_type = _RESETWORLDREQUEST
_RESETWORLDREQUEST.fields_by_name['settings'].message_type = _RESETWORLDREQUEST_SETTINGSENTRY
_READPROPERTYRESPONSE_PROPERTIESENTRY.fields_by_name['value'].message_type = _TENSOR
_READPROPERTYRESPONSE_PROPERTIESENTRY.containing_type = _READPROPERTYRESPONSE
_READPROPERTYRESPONSE.fields_by_name['properties'].message_type = _READPROPERTYRESPONSE_PROPERTIESENTRY
_WRITEPROPERTYREQUEST_PROPERTIESENTRY.fields_by_name['value'].message_type = _TENSOR
_WRITEPROPERTYREQUEST_PROPERTIESENTRY.containing_type = _WRITEPROPERTYREQUEST
_WRITEPROPERTYREQUEST.fields_by_name['properties'].message_type = _WRITEPROPERTYREQUEST_PROPERTIESENTRY
_LISTPROPERTYRESPONSE_PROPERTY.fields_by_name['spec'].message_type = _TENSORSPEC
_LISTPROPERTYRESPONSE_PROPERTY.containing_type = _LISTPROPERTYRESPONSE
_LISTPROPERTYRESPONSE_PROPERTIESENTRY.fields_by_name['value'].message_type = _LISTPROPERTYRESPONSE_PROPERTY
_LISTPROPERTYRESPONSE_PROPERTIESENTRY.containing_type = _LISTPROPERTYRESPONSE
_LISTPROPERTYRESPONSE.fields_by_name['properties'].message_type = _LISTPROPERTYRESPONSE_PROPERTIESENTRY
_ENVIRONMENTREQUEST.fields_by_name['create_world'].message_type = _CREATEWORLDREQUEST
_ENVIRONMENTREQUEST.fields_by_name['join_world'].message_type = _JOINWORLDREQUEST
_ENVIRONMENTREQUEST.fields_by_name['step'].message_type = _STEPREQUEST
_ENVIRONMENTREQUEST.fields_by_name['reset'].message_type = _RESETREQUEST
_ENVIRONMENTREQUEST.fields_by_name['reset_world'].message_type = _RESETWORLDREQUEST
_ENVIRONMENTREQUEST.fields_by_name['leave_world'].message_type = _LEAVEWORLDREQUEST
_ENVIRONMENTREQUEST.fields_by_name['destroy_world'].message_type = _DESTROYWORLDREQUEST
_ENVIRONMENTREQUEST.fields_by_name['read_property'].message_type = _READPROPERTYREQUEST
_ENVIRONMENTREQUEST.fields_by_name['write_property'].message_type = _WRITEPROPERTYREQUEST
_ENVIRONMENTREQUEST.fields_by_name['list_property'].message_type = _LISTPROPERTYREQUEST
_ENVIRONMENTREQUEST.fields_by_name['extension'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['create_world'])
_ENVIRONMENTREQUEST.fields_by_name['create_world'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['join_world'])
_ENVIRONMENTREQUEST.fields_by_name['join_world'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['step'])
_ENVIRONMENTREQUEST.fields_by_name['step'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['reset'])
_ENVIRONMENTREQUEST.fields_by_name['reset'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['reset_world'])
_ENVIRONMENTREQUEST.fields_by_name['reset_world'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['leave_world'])
_ENVIRONMENTREQUEST.fields_by_name['leave_world'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['destroy_world'])
_ENVIRONMENTREQUEST.fields_by_name['destroy_world'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['read_property'])
_ENVIRONMENTREQUEST.fields_by_name['read_property'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['write_property'])
_ENVIRONMENTREQUEST.fields_by_name['write_property'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['list_property'])
_ENVIRONMENTREQUEST.fields_by_name['list_property'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTREQUEST.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTREQUEST.fields_by_name['extension'])
_ENVIRONMENTREQUEST.fields_by_name['extension'].containing_oneof = _ENVIRONMENTREQUEST.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.fields_by_name['create_world'].message_type = _CREATEWORLDRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['join_world'].message_type = _JOINWORLDRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['step'].message_type = _STEPRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['reset'].message_type = _RESETRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['reset_world'].message_type = _RESETWORLDRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['leave_world'].message_type = _LEAVEWORLDRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['destroy_world'].message_type = _DESTROYWORLDRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['read_property'].message_type = _READPROPERTYRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['write_property'].message_type = _WRITEPROPERTYRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['list_property'].message_type = _LISTPROPERTYRESPONSE
_ENVIRONMENTRESPONSE.fields_by_name['extension'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENVIRONMENTRESPONSE.fields_by_name['error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['create_world'])
_ENVIRONMENTRESPONSE.fields_by_name['create_world'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['join_world'])
_ENVIRONMENTRESPONSE.fields_by_name['join_world'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['step'])
_ENVIRONMENTRESPONSE.fields_by_name['step'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['reset'])
_ENVIRONMENTRESPONSE.fields_by_name['reset'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['reset_world'])
_ENVIRONMENTRESPONSE.fields_by_name['reset_world'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['leave_world'])
_ENVIRONMENTRESPONSE.fields_by_name['leave_world'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['destroy_world'])
_ENVIRONMENTRESPONSE.fields_by_name['destroy_world'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['read_property'])
_ENVIRONMENTRESPONSE.fields_by_name['read_property'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['write_property'])
_ENVIRONMENTRESPONSE.fields_by_name['write_property'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['list_property'])
_ENVIRONMENTRESPONSE.fields_by_name['list_property'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['extension'])
_ENVIRONMENTRESPONSE.fields_by_name['extension'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
_ENVIRONMENTRESPONSE.oneofs_by_name['payload'].fields.append(
  _ENVIRONMENTRESPONSE.fields_by_name['error'])
_ENVIRONMENTRESPONSE.fields_by_name['error'].containing_oneof = _ENVIRONMENTRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['Tensor'] = _TENSOR
DESCRIPTOR.message_types_by_name['TensorSpec'] = _TENSORSPEC
DESCRIPTOR.message_types_by_name['CreateWorldRequest'] = _CREATEWORLDREQUEST
DESCRIPTOR.message_types_by_name['CreateWorldResponse'] = _CREATEWORLDRESPONSE
DESCRIPTOR.message_types_by_name['ActionObservationSpecs'] = _ACTIONOBSERVATIONSPECS
DESCRIPTOR.message_types_by_name['JoinWorldRequest'] = _JOINWORLDREQUEST
DESCRIPTOR.message_types_by_name['JoinWorldResponse'] = _JOINWORLDRESPONSE
DESCRIPTOR.message_types_by_name['StepRequest'] = _STEPREQUEST
DESCRIPTOR.message_types_by_name['StepResponse'] = _STEPRESPONSE
DESCRIPTOR.message_types_by_name['ResetRequest'] = _RESETREQUEST
DESCRIPTOR.message_types_by_name['ResetResponse'] = _RESETRESPONSE
DESCRIPTOR.message_types_by_name['ResetWorldRequest'] = _RESETWORLDREQUEST
DESCRIPTOR.message_types_by_name['ResetWorldResponse'] = _RESETWORLDRESPONSE
DESCRIPTOR.message_types_by_name['LeaveWorldRequest'] = _LEAVEWORLDREQUEST
DESCRIPTOR.message_types_by_name['LeaveWorldResponse'] = _LEAVEWORLDRESPONSE
DESCRIPTOR.message_types_by_name['DestroyWorldRequest'] = _DESTROYWORLDREQUEST
DESCRIPTOR.message_types_by_name['DestroyWorldResponse'] = _DESTROYWORLDRESPONSE
DESCRIPTOR.message_types_by_name['ReadPropertyRequest'] = _READPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['ReadPropertyResponse'] = _READPROPERTYRESPONSE
DESCRIPTOR.message_types_by_name['WritePropertyRequest'] = _WRITEPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['WritePropertyResponse'] = _WRITEPROPERTYRESPONSE
DESCRIPTOR.message_types_by_name['ListPropertyRequest'] = _LISTPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['ListPropertyResponse'] = _LISTPROPERTYRESPONSE
DESCRIPTOR.message_types_by_name['EnvironmentRequest'] = _ENVIRONMENTREQUEST
DESCRIPTOR.message_types_by_name['EnvironmentResponse'] = _ENVIRONMENTRESPONSE
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
DESCRIPTOR.enum_types_by_name['EnvironmentStateType'] = _ENVIRONMENTSTATETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tensor = _reflection.GeneratedProtocolMessageType('Tensor', (_message.Message,), {

  'Int8Array' : _reflection.GeneratedProtocolMessageType('Int8Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_INT8ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Int8Array)
    })
  ,

  'Int32Array' : _reflection.GeneratedProtocolMessageType('Int32Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_INT32ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Int32Array)
    })
  ,

  'Int64Array' : _reflection.GeneratedProtocolMessageType('Int64Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_INT64ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Int64Array)
    })
  ,

  'Uint8Array' : _reflection.GeneratedProtocolMessageType('Uint8Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_UINT8ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Uint8Array)
    })
  ,

  'Uint32Array' : _reflection.GeneratedProtocolMessageType('Uint32Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_UINT32ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Uint32Array)
    })
  ,

  'Uint64Array' : _reflection.GeneratedProtocolMessageType('Uint64Array', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_UINT64ARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.Uint64Array)
    })
  ,

  'FloatArray' : _reflection.GeneratedProtocolMessageType('FloatArray', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_FLOATARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.FloatArray)
    })
  ,

  'DoubleArray' : _reflection.GeneratedProtocolMessageType('DoubleArray', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_DOUBLEARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.DoubleArray)
    })
  ,

  'BoolArray' : _reflection.GeneratedProtocolMessageType('BoolArray', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_BOOLARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.BoolArray)
    })
  ,

  'StringArray' : _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_STRINGARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.StringArray)
    })
  ,

  'ProtoArray' : _reflection.GeneratedProtocolMessageType('ProtoArray', (_message.Message,), {
    'DESCRIPTOR' : _TENSOR_PROTOARRAY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor.ProtoArray)
    })
  ,
  'DESCRIPTOR' : _TENSOR,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.Tensor)
  })
_sym_db.RegisterMessage(Tensor)
_sym_db.RegisterMessage(Tensor.Int8Array)
_sym_db.RegisterMessage(Tensor.Int32Array)
_sym_db.RegisterMessage(Tensor.Int64Array)
_sym_db.RegisterMessage(Tensor.Uint8Array)
_sym_db.RegisterMessage(Tensor.Uint32Array)
_sym_db.RegisterMessage(Tensor.Uint64Array)
_sym_db.RegisterMessage(Tensor.FloatArray)
_sym_db.RegisterMessage(Tensor.DoubleArray)
_sym_db.RegisterMessage(Tensor.BoolArray)
_sym_db.RegisterMessage(Tensor.StringArray)
_sym_db.RegisterMessage(Tensor.ProtoArray)

TensorSpec = _reflection.GeneratedProtocolMessageType('TensorSpec', (_message.Message,), {

  'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
    'DESCRIPTOR' : _TENSORSPEC_VALUE,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.TensorSpec.Value)
    })
  ,
  'DESCRIPTOR' : _TENSORSPEC,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.TensorSpec)
  })
_sym_db.RegisterMessage(TensorSpec)
_sym_db.RegisterMessage(TensorSpec.Value)

CreateWorldRequest = _reflection.GeneratedProtocolMessageType('CreateWorldRequest', (_message.Message,), {

  'SettingsEntry' : _reflection.GeneratedProtocolMessageType('SettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEWORLDREQUEST_SETTINGSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.CreateWorldRequest.SettingsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEWORLDREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.CreateWorldRequest)
  })
_sym_db.RegisterMessage(CreateWorldRequest)
_sym_db.RegisterMessage(CreateWorldRequest.SettingsEntry)

CreateWorldResponse = _reflection.GeneratedProtocolMessageType('CreateWorldResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORLDRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.CreateWorldResponse)
  })
_sym_db.RegisterMessage(CreateWorldResponse)

ActionObservationSpecs = _reflection.GeneratedProtocolMessageType('ActionObservationSpecs', (_message.Message,), {

  'ActionsEntry' : _reflection.GeneratedProtocolMessageType('ActionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONOBSERVATIONSPECS_ACTIONSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ActionObservationSpecs.ActionsEntry)
    })
  ,

  'ObservationsEntry' : _reflection.GeneratedProtocolMessageType('ObservationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ActionObservationSpecs.ObservationsEntry)
    })
  ,
  'DESCRIPTOR' : _ACTIONOBSERVATIONSPECS,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ActionObservationSpecs)
  })
_sym_db.RegisterMessage(ActionObservationSpecs)
_sym_db.RegisterMessage(ActionObservationSpecs.ActionsEntry)
_sym_db.RegisterMessage(ActionObservationSpecs.ObservationsEntry)

JoinWorldRequest = _reflection.GeneratedProtocolMessageType('JoinWorldRequest', (_message.Message,), {

  'SettingsEntry' : _reflection.GeneratedProtocolMessageType('SettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOINWORLDREQUEST_SETTINGSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.JoinWorldRequest.SettingsEntry)
    })
  ,
  'DESCRIPTOR' : _JOINWORLDREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.JoinWorldRequest)
  })
_sym_db.RegisterMessage(JoinWorldRequest)
_sym_db.RegisterMessage(JoinWorldRequest.SettingsEntry)

JoinWorldResponse = _reflection.GeneratedProtocolMessageType('JoinWorldResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOINWORLDRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.JoinWorldResponse)
  })
_sym_db.RegisterMessage(JoinWorldResponse)

StepRequest = _reflection.GeneratedProtocolMessageType('StepRequest', (_message.Message,), {

  'ActionsEntry' : _reflection.GeneratedProtocolMessageType('ActionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STEPREQUEST_ACTIONSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.StepRequest.ActionsEntry)
    })
  ,
  'DESCRIPTOR' : _STEPREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.StepRequest)
  })
_sym_db.RegisterMessage(StepRequest)
_sym_db.RegisterMessage(StepRequest.ActionsEntry)

StepResponse = _reflection.GeneratedProtocolMessageType('StepResponse', (_message.Message,), {

  'ObservationsEntry' : _reflection.GeneratedProtocolMessageType('ObservationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STEPRESPONSE_OBSERVATIONSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.StepResponse.ObservationsEntry)
    })
  ,
  'DESCRIPTOR' : _STEPRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.StepResponse)
  })
_sym_db.RegisterMessage(StepResponse)
_sym_db.RegisterMessage(StepResponse.ObservationsEntry)

ResetRequest = _reflection.GeneratedProtocolMessageType('ResetRequest', (_message.Message,), {

  'SettingsEntry' : _reflection.GeneratedProtocolMessageType('SettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESETREQUEST_SETTINGSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetRequest.SettingsEntry)
    })
  ,
  'DESCRIPTOR' : _RESETREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetRequest)
  })
_sym_db.RegisterMessage(ResetRequest)
_sym_db.RegisterMessage(ResetRequest.SettingsEntry)

ResetResponse = _reflection.GeneratedProtocolMessageType('ResetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetResponse)
  })
_sym_db.RegisterMessage(ResetResponse)

ResetWorldRequest = _reflection.GeneratedProtocolMessageType('ResetWorldRequest', (_message.Message,), {

  'SettingsEntry' : _reflection.GeneratedProtocolMessageType('SettingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESETWORLDREQUEST_SETTINGSENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetWorldRequest.SettingsEntry)
    })
  ,
  'DESCRIPTOR' : _RESETWORLDREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetWorldRequest)
  })
_sym_db.RegisterMessage(ResetWorldRequest)
_sym_db.RegisterMessage(ResetWorldRequest.SettingsEntry)

ResetWorldResponse = _reflection.GeneratedProtocolMessageType('ResetWorldResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETWORLDRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ResetWorldResponse)
  })
_sym_db.RegisterMessage(ResetWorldResponse)

LeaveWorldRequest = _reflection.GeneratedProtocolMessageType('LeaveWorldRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEAVEWORLDREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.LeaveWorldRequest)
  })
_sym_db.RegisterMessage(LeaveWorldRequest)

LeaveWorldResponse = _reflection.GeneratedProtocolMessageType('LeaveWorldResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEAVEWORLDRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.LeaveWorldResponse)
  })
_sym_db.RegisterMessage(LeaveWorldResponse)

DestroyWorldRequest = _reflection.GeneratedProtocolMessageType('DestroyWorldRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESTROYWORLDREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.DestroyWorldRequest)
  })
_sym_db.RegisterMessage(DestroyWorldRequest)

DestroyWorldResponse = _reflection.GeneratedProtocolMessageType('DestroyWorldResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESTROYWORLDRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.DestroyWorldResponse)
  })
_sym_db.RegisterMessage(DestroyWorldResponse)

ReadPropertyRequest = _reflection.GeneratedProtocolMessageType('ReadPropertyRequest', (_message.Message,), {
  'DESCRIPTOR' : _READPROPERTYREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ReadPropertyRequest)
  })
_sym_db.RegisterMessage(ReadPropertyRequest)

ReadPropertyResponse = _reflection.GeneratedProtocolMessageType('ReadPropertyResponse', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _READPROPERTYRESPONSE_PROPERTIESENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ReadPropertyResponse.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _READPROPERTYRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ReadPropertyResponse)
  })
_sym_db.RegisterMessage(ReadPropertyResponse)
_sym_db.RegisterMessage(ReadPropertyResponse.PropertiesEntry)

WritePropertyRequest = _reflection.GeneratedProtocolMessageType('WritePropertyRequest', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _WRITEPROPERTYREQUEST_PROPERTIESENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.WritePropertyRequest.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _WRITEPROPERTYREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.WritePropertyRequest)
  })
_sym_db.RegisterMessage(WritePropertyRequest)
_sym_db.RegisterMessage(WritePropertyRequest.PropertiesEntry)

WritePropertyResponse = _reflection.GeneratedProtocolMessageType('WritePropertyResponse', (_message.Message,), {
  'DESCRIPTOR' : _WRITEPROPERTYRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.WritePropertyResponse)
  })
_sym_db.RegisterMessage(WritePropertyResponse)

ListPropertyRequest = _reflection.GeneratedProtocolMessageType('ListPropertyRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROPERTYREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ListPropertyRequest)
  })
_sym_db.RegisterMessage(ListPropertyRequest)

ListPropertyResponse = _reflection.GeneratedProtocolMessageType('ListPropertyResponse', (_message.Message,), {

  'Property' : _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
    'DESCRIPTOR' : _LISTPROPERTYRESPONSE_PROPERTY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ListPropertyResponse.Property)
    })
  ,

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPROPERTYRESPONSE_PROPERTIESENTRY,
    '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
    # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ListPropertyResponse.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPROPERTYRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.ListPropertyResponse)
  })
_sym_db.RegisterMessage(ListPropertyResponse)
_sym_db.RegisterMessage(ListPropertyResponse.Property)
_sym_db.RegisterMessage(ListPropertyResponse.PropertiesEntry)

EnvironmentRequest = _reflection.GeneratedProtocolMessageType('EnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTREQUEST,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.EnvironmentRequest)
  })
_sym_db.RegisterMessage(EnvironmentRequest)

EnvironmentResponse = _reflection.GeneratedProtocolMessageType('EnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTRESPONSE,
  '__module__' : 'dm_env_rpc.v1.dm_env_rpc_pb2'
  # @@protoc_insertion_point(class_scope:dm_env_rpc.v1.EnvironmentResponse)
  })
_sym_db.RegisterMessage(EnvironmentResponse)


_CREATEWORLDREQUEST_SETTINGSENTRY._options = None
_ACTIONOBSERVATIONSPECS_ACTIONSENTRY._options = None
_ACTIONOBSERVATIONSPECS_OBSERVATIONSENTRY._options = None
_JOINWORLDREQUEST_SETTINGSENTRY._options = None
_STEPREQUEST_ACTIONSENTRY._options = None
_STEPRESPONSE_OBSERVATIONSENTRY._options = None
_RESETREQUEST_SETTINGSENTRY._options = None
_RESETWORLDREQUEST_SETTINGSENTRY._options = None
_READPROPERTYRESPONSE_PROPERTIESENTRY._options = None
_WRITEPROPERTYREQUEST_PROPERTIESENTRY._options = None
_LISTPROPERTYRESPONSE_PROPERTIESENTRY._options = None

_ENVIRONMENT = _descriptor.ServiceDescriptor(
  name='Environment',
  full_name='dm_env_rpc.v1.Environment',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5419,
  serialized_end=5520,
  methods=[
  _descriptor.MethodDescriptor(
    name='Process',
    full_name='dm_env_rpc.v1.Environment.Process',
    index=0,
    containing_service=None,
    input_type=_ENVIRONMENTREQUEST,
    output_type=_ENVIRONMENTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENVIRONMENT)

DESCRIPTOR.services_by_name['Environment'] = _ENVIRONMENT

# @@protoc_insertion_point(module_scope)
